package org.ow2.bonita.persistence.db;

import java.util.Set;

import org.ow2.bonita.facade.def.majorElement.ProcessFullDefinition;
import org.ow2.bonita.facade.def.majorElement.impl.ProcessDefinitionImpl;
import org.ow2.bonita.facade.runtime.ProcessFullInstance;
import org.ow2.bonita.facade.runtime.impl.ProcessFullInstanceImpl;
import org.ow2.bonita.services.Archiver;
import org.ow2.bonita.services.Querier;
import org.ow2.bonita.util.ExceptionManager;
import org.ow2.bonita.util.Misc;

/**
 *
 * @author Thomas Gueze
 *
 */
public class DbHistory extends AbstractDbQuerier implements Archiver, Querier {

  public DbHistory(final String name) {
    super(name, new DbQuerierBufferImpl());
  }

  public void archive(final ProcessFullDefinition process) {
    Misc.checkArgsNotNull(process);
    if (getProcess(process.getUUID()) == null) {
      final ProcessFullDefinition pack = new ProcessDefinitionImpl(process);
      this.buffer.addProcess(pack);
      getQuerierDbSession().save(pack);
    } else {
    	String message = ExceptionManager.getInstance().getFullMessage(
    			"bsi_DH_1", process);
      throw new IllegalArgumentException(message);
    }
  }

  public void archive(final ProcessFullInstance processInst) {
    Misc.checkArgsNotNull(processInst);
    if (getProcessInstance(processInst.getUUID()) == null) {
      final ProcessFullInstance instance = new ProcessFullInstanceImpl(processInst);
      this.buffer.addInstance(instance);
      getQuerierDbSession().save(instance);
    } else {
    	String message = ExceptionManager.getInstance().getFullMessage(
    			"bsi_DH_2", processInst);
      throw new IllegalArgumentException(message);
    }
  }

  public void remove(final ProcessFullDefinition process) {
    Misc.checkArgsNotNull(process);
    this.buffer.removeProcess(process);
    getQuerierDbSession().delete(process);
  }

  public void remove(final ProcessFullInstance processInst) {
    Misc.checkArgsNotNull(processInst);
    this.buffer.removeInstance(processInst);
    getQuerierDbSession().delete(processInst);
  }

  public void clear() {
    final Set<ProcessFullDefinition> processes = getQuerierDbSession().getProcesses();
    Set<ProcessFullInstance> processInstances;
    for (final ProcessFullDefinition processDef : processes) {
    	processInstances = getQuerierDbSession().getProcessInstances(processDef.getUUID());
        for (final ProcessFullInstance processInstance : processInstances) {
          this.buffer.removeInstance(processInstance);
          getQuerierDbSession().delete(processInstance);
        }
      this.buffer.removeProcess(processDef);
      getQuerierDbSession().delete(processDef);
    }
  }

}
