/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.persistence.db;

import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

import org.ow2.bonita.facade.def.majorElement.ProcessFullDefinition;
import org.ow2.bonita.facade.runtime.ProcessFullInstance;
import org.ow2.bonita.facade.uuid.ProcessDefinitionUUID;
import org.ow2.bonita.facade.uuid.ProcessInstanceUUID;


public class DbQuerierBufferImpl implements DbQuerierBuffer {

  //runtime : instance, activity, tasks
  //definition : package, process, activity
  
  protected Map<ProcessInstanceUUID, ProcessFullInstance> instances =
    new HashMap<ProcessInstanceUUID, ProcessFullInstance>();
  
  protected Map<ProcessDefinitionUUID, ProcessFullDefinition> processes =
    new HashMap<ProcessDefinitionUUID, ProcessFullDefinition>();
  
  protected Map<ProcessInstanceUUID, ProcessFullInstance> removedInstances =
    new HashMap<ProcessInstanceUUID, ProcessFullInstance>();
  
  protected Map<ProcessDefinitionUUID, ProcessFullDefinition> removedProcesses =
    new HashMap<ProcessDefinitionUUID, ProcessFullDefinition>();
  
  /**
   * INSTANCES
   */
  
  public Map<ProcessInstanceUUID, ProcessFullInstance> getInstances() {
    return instances;
  }
  public Set<ProcessFullInstance> getInstancesSet() {
    Set<ProcessFullInstance> result = new HashSet<ProcessFullInstance>();
    result.addAll(instances.values());
    return result;
  }
  public ProcessFullInstance getInstance(ProcessInstanceUUID instanceUUID) {
    return instances.get(instanceUUID);
  }
  public boolean isInstanceRemoved(ProcessInstanceUUID instanceUUID) {
    return removedInstances.containsKey(instanceUUID);
  }
  public void addInstance(ProcessFullInstance instance) {
    instances.put(instance.getUUID(), instance);
    removedInstances.remove(instance.getUUID());
  }
  public boolean containsInstance(ProcessInstanceUUID instanceUUID) {
    return instances.containsKey(instanceUUID);
  }
  public void removeInstance(ProcessFullInstance instance) {
    ProcessInstanceUUID instanceUUID = instance.getUUID();
    instances.remove(instanceUUID);
    removedInstances.put(instanceUUID, instance);
  }
  
  /**
   * PROCESSE
   */
  public Map<ProcessDefinitionUUID, ProcessFullDefinition> getProcesses() {
    return processes;
  }
  
  public Map<ProcessDefinitionUUID, ProcessFullDefinition> getProcesses(String processId) {
    Map<ProcessDefinitionUUID, ProcessFullDefinition> returnProcesses = 
      new HashMap<ProcessDefinitionUUID, ProcessFullDefinition>();
    for (ProcessFullDefinition processDef : processes.values()) {
      if (processDef.getProcessId().equals(processId)) {
        returnProcesses.put(processDef.getUUID(), processDef);
      }
    }
    return returnProcesses;
  }
  
  public Set<ProcessFullDefinition> getProcessesSet() {
    Set<ProcessFullDefinition> result = new HashSet<ProcessFullDefinition>();
    result.addAll(processes.values());
    return result;
  }
  public ProcessFullDefinition getProcess(ProcessDefinitionUUID processUUID) {
    return processes.get(processUUID);
  }
  public boolean isProcessRemoved(ProcessDefinitionUUID processUUID) {
    return removedProcesses.containsKey(processUUID);
  }
  public void addProcess(ProcessFullDefinition pack) {
    processes.put(pack.getUUID(), pack);
    removedProcesses.remove(pack.getUUID());
  }
  public boolean containsProcess(ProcessDefinitionUUID processUUID) {
    return processes.containsKey(processUUID);
  }
  public void removeProcess(ProcessFullDefinition pack) {
	  ProcessDefinitionUUID processUUID = pack.getUUID();
    processes.remove(processUUID);
    removedProcesses.put(processUUID, pack);
  }
}


