/**
 * Copyright (C) 2007  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.util;

import org.ow2.bonita.facade.def.majorElement.ProcessFullDefinition;
import org.ow2.bonita.facade.runtime.ProcessFullInstance;
import org.ow2.bonita.services.Archivable;
import org.ow2.bonita.services.Archiver;
import org.ow2.bonita.services.Recorder;

/**
 * @author Pierre Vigneras
 * @date Mar 6, 2008
 */
public abstract class ArchiveTool {

  private ArchiveTool() { }

  /**
   * Perform a all-or-nothing archive.
   *
   * This method does the following: it first tries to archive the given Archivable
   * into the specified {@link Archiver}. If it succeeds and only in this case, it tries
   * to remove the given record from the specified
   *
   * @param record a record
   * @throws AtomicArchiveException if archiving failed.
   */
  public static void atomicArchive(final Archivable archivable,
      final Recorder recorder,
      final Archiver archiver) {
    if (!(archivable instanceof ProcessFullDefinition) && !(archivable instanceof ProcessFullInstance)) {
    	String message = ExceptionManager.getInstance().getFullMessage(
    			"bsi_AT_1", archivable, (archivable != null ? " of type: " + archivable.getClass().getName() : ""));
      throw new IllegalArgumentException(message);
    }
    try {
      if (archivable instanceof ProcessFullDefinition) {
        archiver.archive((ProcessFullDefinition) archivable);
      } else {
        // archivable instanceof ProcessFullInstance because of previous checks
        archiver.archive((ProcessFullInstance) archivable);
      }
    } catch (final Exception e) {
    	String message = ExceptionManager.getInstance().getFullMessage(
    			"bsi_AT_2", archivable, archiver);
      throw new AtomicArchiveException(message, e);
    }
    try {
      if (archivable instanceof ProcessFullDefinition) {
        recorder.remove((ProcessFullDefinition) archivable);
      } else {
        // archivable instanceof ProcessFullInstance because of previous checks
        recorder.remove((ProcessFullInstance) archivable);
      }
    } catch (final Exception e) {
    	String message = ExceptionManager.getInstance().getFullMessage(
    			"bsi_AT_3", archivable, recorder);
      throw new AtomicArchiveException(message, e);
    }
  }

}
